<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package neblue
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="http://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site"><div class="inner">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'neblue' ); ?></a>

	<header id="masthead" class="site-header">
		<div class="site-branding">
			<?php
			the_custom_logo();
			if ( is_front_page() && is_home() ) : ?>
				<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
			<?php else : ?>
				<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
			<?php
			endif;
			?>

			<div class="site-social">
<?php if(get_theme_mod('social_email')):?>
<a href="<?php echo esc_url('mailto:'.antispambot(get_theme_mod('social_email'))); ?>" title="<?php esc_attr_e('Send Us an Email', 'neblue'); ?>"><i class="fa fa-envelope-o" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_skype')):?>
<a href="skype:<?php echo esc_html(get_theme_mod('social_skype')); ?>?userinfo" title="<?php esc_attr_e('Contact Us on Skype', 'neblue'); ?>"><i class="fa fa-skype" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_facebook')):?>
<a href="<?php echo esc_url(get_theme_mod('social_facebook')); ?>" target="_blank" title="<?php esc_attr_e('Find Us on Facebook', 'neblue'); ?>"><i class="fa fa-facebook" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_twitter')):?>
<a href="<?php echo esc_url(get_theme_mod('social_twitter')); ?>" target="_blank" title="<?php esc_attr_e('Follow Us on Twitter', 'neblue'); ?>"><i class="fa fa-twitter" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_google_plus')):?>
<a href="<?php echo esc_url(get_theme_mod('social_google_plus')); ?>" target="_blank" title="<?php esc_attr_e('Find Us on Google Plus', 'neblue'); ?>"><i class="fa fa-google-plus" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_youtube')):?>
<a href="<?php echo esc_url(get_theme_mod('social_youtube')); ?>" target="_blank" title="<?php esc_attr_e('View our YouTube Channel', 'neblue'); ?>"><i class="fa fa-youtube" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_instagram')):?>
<a href="<?php echo esc_url(get_theme_mod('social_instagram')); ?>" target="_blank" title="<?php esc_attr_e('Follow Us on Instagram', 'neblue'); ?>"><i class="fa fa-instagram" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_pinterest')):?>
<a href="<?php echo esc_url(get_theme_mod('social_pinterest')); ?>" target="_blank" title="<?php esc_attr_e('Pin Us on Pinterest', 'neblue'); ?>"><i class="fa fa-pinterest" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_linkedin')):?>
<a href="<?php echo esc_url(get_theme_mod('social_linkedin')); ?>" target="_blank" title="<?php esc_attr_e('Find Us on LinkedIn', 'neblue'); ?>"><i class="fa fa-linkedin" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_tumblr')):?>
<a href="<?php echo esc_url(get_theme_mod('social_tumblr')); ?>" target="_blank" title="<?php esc_attr_e('Find Us on Tumblr', 'neblue'); ?>"><i class="fa fa-tumblr" aria-hidden="true"></i></a>
<?php endif; ?>
<?php if(get_theme_mod('social_flickr')):?>
<a href="<?php echo esc_url(get_theme_mod('social_flickr')); ?>" target="_blank" title="<?php esc_attr_e('Find Us on Flickr', 'neblue'); ?>"><i class="fa fa-flickr" aria-hidden="true"></i></a>
<?php endif; ?>
				<div class="clear"></div>
    		</div>

            <div class="clear"></div>
		</div><!-- .site-branding -->

	    <nav id="site-navigation" class="main-navigation">
	        <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false" value="<?php echo esc_attr_x( 'Menu', 'primary menu', 'neblue' ); ?>"><i class="fa fa-bars" aria-hidden="true"></i><span class="screen-reader-text"><?php echo esc_html_x( 'Menu', 'primary menu', 'neblue' ); ?></span></button>
	        <?php
	            wp_nav_menu( array(
	                'theme_location' => 'menu-1',
	                'menu_id'        => 'primary-menu',
	            ) );
	        ?>
	        <div class="clear"></div>
	    </nav><!-- #site-navigation -->
	</header><!-- #masthead -->

<?php
if(get_theme_mod('activate_slider',0)){
	if(is_front_page()){
?>
		<div class="site-slider"><div class="inner"><?php neblue_slider();?><div class="clear"></div></div></div>
<?php
	}
}
?>

	<div id="content" class="site-content">
